import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class PennyArcade(BasicComicModule):
    latestUrl = 'http://www.penny-arcade.com/view.php3'
    imageUrl = 'http://www.penny-arcade.com/view.php3?date=%s&res=l'
    imageSearch = re.compile(r'<img src="(/images/\d{4}/\d{8}..+?)"', re.IGNORECASE)
    prevSearch = re.compile(r'<a href="(view.php3\?date=\d{4}-\d{2}-\d{2}&res=l)">', re.IGNORECASE)
    help = 'Index format: yyyy-mm-dd'
